@@ -1,4 +1,4 @@
-# copyright 2004-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2004-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of yams.
@@ -90,9 +90,9 @@ class SizeConstraint(BaseConstraint):
     def __str__(self):
         res = 'size'
         if self.max is not None:
-            res = '%s < %s' % (res, self.max)
+            res = '%s <= %s' % (res, self.max)
         if self.min is not None:
-            res = '%s < %s' % (self.min, res)
+            res = '%s <= %s' % (self.min, res)
         return res
 
     def check_consistency(self, subjschema, objschema, rdef):
@@ -125,9 +125,11 @@ class SizeConstraint(BaseConstraint):
 
     def failed_message(self, value, _=unicode):
         if self.max is not None and len(value) > self.max:
-            return _('value should have maximum size of %s') % self.max
+            return _('value should have maximum size of %s but found %s') % (
+                self.max, len(value))
         if self.min is not None and len(value) < self.min:
-            return _('value should have minimum size of %s') % self.min
+            return _('value should have minimum size of %s but found %s') % (
+                self.min, len(value))
         assert False, 'shouldnt be there'
 
     def serialize(self):
@@ -231,8 +233,8 @@ class BoundaryConstraint(BaseConstraint):
         return OPERATORS[self.operator](value, boundary)
 
     def failed_message(self, value, _=unicode):
-        return _("value must be %(op)s %(boundary)s") % {
-            'op': self.operator, 'boundary': self.boundary}
+        return _("value %(value)s must be %(op)s %(boundary)s") % {
+            'value': value, 'op': self.operator, 'boundary': self.boundary}
 
     def serialize(self):
         """simple text serialization"""
@@ -284,11 +286,11 @@ class IntervalBoundConstraint(BaseConstraint):
 
     def failed_message(self, value, _=unicode):
         if self.minvalue is not None and value < self.minvalue:
-            return _("value must be >= %(boundary)s") % {
-                'boundary': self.minvalue}
+            return _("value %(value)s must be >= %(boundary)s") % {
+                'value': value, 'boundary': self.minvalue}
         if self.maxvalue is not None and value > self.maxvalue:
-            return _("value must be <= %(boundary)s") % {
-                'boundary': self.maxvalue}
+            return _("value %(value)s must be <= %(boundary)s") % {
+                'value': value, 'boundary': self.maxvalue}
         assert False, 'shouldnt be there'
 
     def serialize(self):
@@ -503,6 +505,7 @@ BASE_CHECKERS = {
     'Interval' : yes,
     'String' :   check_string,
     'Int' :      check_int,
+    'BigInt' :   check_int,
     'Float' :    check_float,
     'Decimal' :  check_decimal,
     'Boolean' :  check_boolean,
@@ -511,7 +514,10 @@ BASE_CHECKERS = {
     }
 
 BASE_CONVERTERS = {
+    'String' :  unicode,
+    'Password':  str,
     'Int' :      int,
+    'BigInt' :   int,
     'Float' :    float,
     'Boolean' :  bool,
     'Decimal' :  decimal.Decimal,
